#
# spec file for package python-pydantic-core
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor test%{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-pydantic-core%{psuffix}
Version:        2.18.4
Release:        1.0.2.1.sr20240605
Summary:        Core functionality for pydantic validation and serialization
License:        MIT
URL:            https://github.com/pydantic/pydantic-core
Source0:        https://files.pythonhosted.org/packages/source/p/pydantic-core/pydantic_core-%{version}.tar.gz
Source1:        vendor.tar.xz
BuildRequires:  %{python_module maturin >= 1}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module typing-extensions >= 4.6.0}
BuildRequires:  cargo-packaging
BuildRequires:  python-rpm-macros
# SECTION test requirements
%if %{with test}
BuildRequires:  %{python_module dirty-equals}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pydantic-core == %{version}}
BuildRequires:  %{python_module pytest-benchmark}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest-timeout}
BuildRequires:  %{python_module pytest}
%endif
# /SECTION
BuildRequires:  fdupes
Requires:       python-typing-extensions >= 4.6.0
%python_subpackages

%description
This package provides the core functionality for [pydantic](https://docs.pydantic.dev) validation and serialization.

Pydantic-core is currently around 17x faster than pydantic V1.

%prep
%autosetup -p1 -n pydantic_core-%{version} -a1

%build
# The build takes quite a long time, so we don't want to build this while under test.
%if %{without test}
%pyproject_wheel
%endif

%install
%if %{without test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}
%endif

%check
%if %{with test}
%pytest_arch
%endif

%if %{without test}
%files %{python_files}
%{python_sitearch}/pydantic_core
%{python_sitearch}/pydantic_core-%{version}.dist-info
%endif

%changelog
* Thu Jun  6 2024 Dirk Müller <dmueller@suse.com>
- update to 2.18.4:
  * Bump uuid from 1.7.0 to 1.8.0
  * Bump serde from 1.0.197 to 1.0.203
  * Bump the python-packages group with 6 updates
  * Uprev `jiter` to v0.4.1
- update to 2.18.3:
  * Bump `serde_json` from 1.0.114 to 1.0.116
  * Bump the python-packages group with 7 updates
  * Bump `regex` from 1.10.3 to 1.10.4
  * Bump `pyo3` from 0.21.1 to 0.21.2
  * Bump `uraimo/run-on-arch-action` from 2.7.1 to 2.7.2
* Sat Apr 27 2024 Dirk Müller <dmueller@suse.com>
- update to 2.18.2:
  * Support multiple zeros as an `int`
  * Fix validation of `int`s with leading unary plus
  * Fix interaction between `extra != 'ignore'` and
    `from_attributes=True`
  * Handle error from `Enum`'s `missing` function as
    `ValidationError`
  * Fix memory leak with `Iterable` validation
- update to 2.18.1:
  * allow serialization functions to upgrade warnings to
    exceptions
  * Fix: add `coerce_numbers_to_str option` in `StringSchema`
  * Trim leading zeros before parsing `str` -> `int`
  * Prevent trailing dots in integers
- update to 2.18.0:
  * update to PyO3 0.21 final
  * Add coerce_numbers_to_str option in str_schema
  * caching strings from JSON
  * fix build warnings on python <3.11
  * Fixes for `ser_json_inf_nan` inference
  * Adopt jiter `0.2.0`
- update to 2.17.0:
  * Add benchmarks for serializing model with complete schema
  * Prevent panicking when `__dict__` changes during iteration
  * Fix `TzInfo` equality check based on offset
  * Fix stack overflow due to recursion in some recursive
    serializer schemas.
  * Use PEP570 syntax
  * Fix parsing `BigInt` from `str`
  * Use new typing syntax for `_pydantic_core.pyi`
  * separate `Input` trait `'a` and `'py` lifetimes
  * Fix json serialization when `computed_field` is excluded
  * Implement `Input` for `str`
  * Move list validation to produce an associated type
  * Remove `with_new_extra`
  * Associated types for arguments in Input
  * Associated types for dict in input
  * Remaining associated types
  * Refactor `Input` trait to have single `as_python` cast for
    python inputs
  * Allow case where `__pydantic_extra__` is `None`, even if
    `extra='allow'`
  * Add ability to pass `context` to serialization
  * Add `serialize_as_any` runtime flag support
* Tue Mar 12 2024 Steve Kowalik <steven.kowalik@suse.com>
- Sprinkle in multibuild to avoid build cycles.
* Sat Mar  9 2024 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Mar  6 2024 Steve Kowalik <steven.kowalik@suse.com>
- Initial release of 2.16.3
